==> openshift-model-console-6.5.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleLinkSpecFluentImpl<A extends ConsoleLinkSpecFluent<A>> extends BaseFluent<A> implements ConsoleLinkSpecFluent<A>{
  public ConsoleLinkSpecFluentImpl() {
  }
  public ConsoleLinkSpecFluentImpl(ConsoleLinkSpec instance) {
    this.withApplicationMenu(instance.getApplicationMenu()); 
    this.withHref(instance.getHref()); 
    this.withLocation(instance.getLocation()); 
    this.withNamespaceDashboard(instance.getNamespaceDashboard()); 
    this.withText(instance.getText()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ApplicationMenuSpecBuilder applicationMenu;
  private String href;
  private String location;
  private NamespaceDashboardSpecBuilder namespaceDashboard;
  private String text;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildApplicationMenu instead.
   * @return The buildable object.
   */
  @Deprecated
  public ApplicationMenuSpec getApplicationMenu() {
    return this.applicationMenu!=null ?this.applicationMenu.build():null;
  }
  public ApplicationMenuSpec buildApplicationMenu() {
    return this.applicationMenu!=null ?this.applicationMenu.build():null;
  }
  public A withApplicationMenu(ApplicationMenuSpec applicationMenu) {
    _visitables.get("applicationMenu").remove(this.applicationMenu);
    if (applicationMenu!=null){ this.applicationMenu= new ApplicationMenuSpecBuilder(applicationMenu); _visitables.get("applicationMenu").add(this.applicationMenu);} else { this.applicationMenu = null; _visitables.get("applicationMenu").remove(this.applicationMenu); } return (A) this;
  }
  public Boolean hasApplicationMenu() {
    return this.applicationMenu != null;
  }
  public A withNewApplicationMenu(String imageURL,String section) {
    return (A)withApplicationMenu(new ApplicationMenuSpec(imageURL, section));
  }
  public ConsoleLinkSpecFluent.ApplicationMenuNested<A> withNewApplicationMenu() {
    return new ConsoleLinkSpecFluentImpl.ApplicationMenuNestedImpl();
  }
  public ConsoleLinkSpecFluent.ApplicationMenuNested<A> withNewApplicationMenuLike(ApplicationMenuSpec item) {
    return new ConsoleLinkSpecFluentImpl.ApplicationMenuNestedImpl(item);
  }
  public ConsoleLinkSpecFluent.ApplicationMenuNested<A> editApplicationMenu() {
    return withNewApplicationMenuLike(getApplicationMenu());
  }
  public ConsoleLinkSpecFluent.ApplicationMenuNested<A> editOrNewApplicationMenu() {
    return withNewApplicationMenuLike(getApplicationMenu() != null ? getApplicationMenu(): new ApplicationMenuSpecBuilder().build());
  }
  public ConsoleLinkSpecFluent.ApplicationMenuNested<A> editOrNewApplicationMenuLike(ApplicationMenuSpec item) {
    return withNewApplicationMenuLike(getApplicationMenu() != null ? getApplicationMenu(): item);
  }
  public String getHref() {
    return this.href;
  }
  public A withHref(String href) {
    this.href=href; return (A) this;
  }
  public Boolean hasHref() {
    return this.href != null;
  }
  public String getLocation() {
    return this.location;
  }
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  public Boolean hasLocation() {
    return this.location != null;
  }
  
  /**
   * This method has been deprecated, please use method buildNamespaceDashboard instead.
   * @return The buildable object.
   */
  @Deprecated
  public NamespaceDashboardSpec getNamespaceDashboard() {
    return this.namespaceDashboard!=null ?this.namespaceDashboard.build():null;
  }
  public NamespaceDashboardSpec buildNamespaceDashboard() {
    return this.namespaceDashboard!=null ?this.namespaceDashboard.build():null;
  }
  public A withNamespaceDashboard(NamespaceDashboardSpec namespaceDashboard) {
    _visitables.get("namespaceDashboard").remove(this.namespaceDashboard);
    if (namespaceDashboard!=null){ this.namespaceDashboard= new NamespaceDashboardSpecBuilder(namespaceDashboard); _visitables.get("namespaceDashboard").add(this.namespaceDashboard);} else { this.namespaceDashboard = null; _visitables.get("namespaceDashboard").remove(this.namespaceDashboard); } return (A) this;
  }
  public Boolean hasNamespaceDashboard() {
    return this.namespaceDashboard != null;
  }
  public ConsoleLinkSpecFluent.NamespaceDashboardNested<A> withNewNamespaceDashboard() {
    return new ConsoleLinkSpecFluentImpl.NamespaceDashboardNestedImpl();
  }
  public ConsoleLinkSpecFluent.NamespaceDashboardNested<A> withNewNamespaceDashboardLike(NamespaceDashboardSpec item) {
    return new ConsoleLinkSpecFluentImpl.NamespaceDashboardNestedImpl(item);
  }
  public ConsoleLinkSpecFluent.NamespaceDashboardNested<A> editNamespaceDashboard() {
    return withNewNamespaceDashboardLike(getNamespaceDashboard());
  }
  public ConsoleLinkSpecFluent.NamespaceDashboardNested<A> editOrNewNamespaceDashboard() {
    return withNewNamespaceDashboardLike(getNamespaceDashboard() != null ? getNamespaceDashboard(): new NamespaceDashboardSpecBuilder().build());
  }
  public ConsoleLinkSpecFluent.NamespaceDashboardNested<A> editOrNewNamespaceDashboardLike(NamespaceDashboardSpec item) {
    return withNewNamespaceDashboardLike(getNamespaceDashboard() != null ? getNamespaceDashboard(): item);
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsoleLinkSpecFluentImpl that = (ConsoleLinkSpecFluentImpl) o;
    if (applicationMenu != null ? !applicationMenu.equals(that.applicationMenu) :that.applicationMenu != null) return false;
    if (href != null ? !href.equals(that.href) :that.href != null) return false;
    if (location != null ? !location.equals(that.location) :that.location != null) return false;
    if (namespaceDashboard != null ? !namespaceDashboard.equals(that.namespaceDashboard) :that.namespaceDashboard != null) return false;
    if (text != null ? !text.equals(that.text) :that.text != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applicationMenu,  href,  location,  namespaceDashboard,  text,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationMenu != null) { sb.append("applicationMenu:"); sb.append(applicationMenu + ","); }
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (namespaceDashboard != null) { sb.append("namespaceDashboard:"); sb.append(namespaceDashboard + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ApplicationMenuNestedImpl<N> extends ApplicationMenuSpecFluentImpl<ConsoleLinkSpecFluent.ApplicationMenuNested<N>> implements ConsoleLinkSpecFluent.ApplicationMenuNested<N>,Nested<N>{
    ApplicationMenuNestedImpl(ApplicationMenuSpec item) {
      this.builder = new ApplicationMenuSpecBuilder(this, item);
    }
    ApplicationMenuNestedImpl() {
      this.builder = new ApplicationMenuSpecBuilder(this);
    }
    ApplicationMenuSpecBuilder builder;
    public N and() {
      return (N) ConsoleLinkSpecFluentImpl.this.withApplicationMenu(builder.build());
    }
    public N endApplicationMenu() {
      return and();
    }
    
  }
  class NamespaceDashboardNestedImpl<N> extends NamespaceDashboardSpecFluentImpl<ConsoleLinkSpecFluent.NamespaceDashboardNested<N>> implements ConsoleLinkSpecFluent.NamespaceDashboardNested<N>,Nested<N>{
    NamespaceDashboardNestedImpl(NamespaceDashboardSpec item) {
      this.builder = new NamespaceDashboardSpecBuilder(this, item);
    }
    NamespaceDashboardNestedImpl() {
      this.builder = new NamespaceDashboardSpecBuilder(this);
    }
    NamespaceDashboardSpecBuilder builder;
    public N and() {
      return (N) ConsoleLinkSpecFluentImpl.this.withNamespaceDashboard(builder.build());
    }
    public N endNamespaceDashboard() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleLinkSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsoleLinkSpecFluentImpl<A extends ConsoleLinkSpecFluent<A>> extends BaseFluent<A> implements ConsoleLinkSpecFluent<A>{
  public ConsoleLinkSpecFluentImpl() {
  }
  public ConsoleLinkSpecFluentImpl(ConsoleLinkSpec instance) {
    if (instance != null) {
      this.withApplicationMenu(instance.getApplicationMenu());
      this.withHref(instance.getHref());
      this.withLocation(instance.getLocation());
      this.withNamespaceDashboard(instance.getNamespaceDashboard());
      this.withText(instance.getText());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ApplicationMenuSpecBuilder applicationMenu;
  private String href;
  private String location;
  private NamespaceDashboardSpecBuilder namespaceDashboard;
  private String text;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildApplicationMenu instead.
   * @return The buildable object.
   */
  @Deprecated
  public ApplicationMenuSpec getApplicationMenu() {
    return this.applicationMenu!=null ?this.applicationMenu.build():null;
  }
  public ApplicationMenuSpec buildApplicationMenu() {
    return this.applicationMenu!=null ?this.applicationMenu.build():null;
  }
  public A withApplicationMenu(ApplicationMenuSpec applicationMenu) {
    _visitables.get("applicationMenu").remove(this.applicationMenu);
    if (applicationMenu!=null){ this.applicationMenu= new ApplicationMenuSpecBuilder(applicationMenu); _visitables.get("applicationMenu").add(this.applicationMenu);} else { this.applicationMenu = null; _visitables.get("applicationMenu").remove(this.applicationMenu); } return (A) this;
  }
  public Boolean hasApplicationMenu() {
    return this.applicationMenu != null;
  }
  public A withNewApplicationMenu(String imageURL,String section) {
    return (A)withApplicationMenu(new ApplicationMenuSpec(imageURL, section));
  }
  public ConsoleLinkSpecFluentImpl.ApplicationMenuNested<A> withNewApplicationMenu() {
    return new ConsoleLinkSpecFluentImpl.ApplicationMenuNestedImpl();
  }
  public ConsoleLinkSpecFluentImpl.ApplicationMenuNested<A> withNewApplicationMenuLike(ApplicationMenuSpec item) {
    return new ConsoleLinkSpecFluentImpl.ApplicationMenuNestedImpl(item);
  }
  public ConsoleLinkSpecFluentImpl.ApplicationMenuNested<A> editApplicationMenu() {
    return withNewApplicationMenuLike(getApplicationMenu());
  }
  public ConsoleLinkSpecFluentImpl.ApplicationMenuNested<A> editOrNewApplicationMenu() {
    return withNewApplicationMenuLike(getApplicationMenu() != null ? getApplicationMenu(): new ApplicationMenuSpecBuilder().build());
  }
  public ConsoleLinkSpecFluentImpl.ApplicationMenuNested<A> editOrNewApplicationMenuLike(ApplicationMenuSpec item) {
    return withNewApplicationMenuLike(getApplicationMenu() != null ? getApplicationMenu(): item);
  }
  public String getHref() {
    return this.href;
  }
  public A withHref(String href) {
    this.href=href; return (A) this;
  }
  public Boolean hasHref() {
    return this.href != null;
  }
  public String getLocation() {
    return this.location;
  }
  public A withLocation(String location) {
    this.location=location; return (A) this;
  }
  public Boolean hasLocation() {
    return this.location != null;
  }
  
  /**
   * This method has been deprecated, please use method buildNamespaceDashboard instead.
   * @return The buildable object.
   */
  @Deprecated
  public NamespaceDashboardSpec getNamespaceDashboard() {
    return this.namespaceDashboard!=null ?this.namespaceDashboard.build():null;
  }
  public NamespaceDashboardSpec buildNamespaceDashboard() {
    return this.namespaceDashboard!=null ?this.namespaceDashboard.build():null;
  }
  public A withNamespaceDashboard(NamespaceDashboardSpec namespaceDashboard) {
    _visitables.get("namespaceDashboard").remove(this.namespaceDashboard);
    if (namespaceDashboard!=null){ this.namespaceDashboard= new NamespaceDashboardSpecBuilder(namespaceDashboard); _visitables.get("namespaceDashboard").add(this.namespaceDashboard);} else { this.namespaceDashboard = null; _visitables.get("namespaceDashboard").remove(this.namespaceDashboard); } return (A) this;
  }
  public Boolean hasNamespaceDashboard() {
    return this.namespaceDashboard != null;
  }
  public ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<A> withNewNamespaceDashboard() {
    return new ConsoleLinkSpecFluentImpl.NamespaceDashboardNestedImpl();
  }
  public ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<A> withNewNamespaceDashboardLike(NamespaceDashboardSpec item) {
    return new ConsoleLinkSpecFluentImpl.NamespaceDashboardNestedImpl(item);
  }
  public ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<A> editNamespaceDashboard() {
    return withNewNamespaceDashboardLike(getNamespaceDashboard());
  }
  public ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<A> editOrNewNamespaceDashboard() {
    return withNewNamespaceDashboardLike(getNamespaceDashboard() != null ? getNamespaceDashboard(): new NamespaceDashboardSpecBuilder().build());
  }
  public ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<A> editOrNewNamespaceDashboardLike(NamespaceDashboardSpec item) {
    return withNewNamespaceDashboardLike(getNamespaceDashboard() != null ? getNamespaceDashboard(): item);
  }
  public String getText() {
    return this.text;
  }
  public A withText(String text) {
    this.text=text; return (A) this;
  }
  public Boolean hasText() {
    return this.text != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleLinkSpecFluentImpl that = (ConsoleLinkSpecFluentImpl) o;
    if (!java.util.Objects.equals(applicationMenu, that.applicationMenu)) return false;

    if (!java.util.Objects.equals(href, that.href)) return false;

    if (!java.util.Objects.equals(location, that.location)) return false;

    if (!java.util.Objects.equals(namespaceDashboard, that.namespaceDashboard)) return false;

    if (!java.util.Objects.equals(text, that.text)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applicationMenu,  href,  location,  namespaceDashboard,  text,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applicationMenu != null) { sb.append("applicationMenu:"); sb.append(applicationMenu + ","); }
    if (href != null) { sb.append("href:"); sb.append(href + ","); }
    if (location != null) { sb.append("location:"); sb.append(location + ","); }
    if (namespaceDashboard != null) { sb.append("namespaceDashboard:"); sb.append(namespaceDashboard + ","); }
    if (text != null) { sb.append("text:"); sb.append(text + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ApplicationMenuNestedImpl<N> extends ApplicationMenuSpecFluentImpl<ConsoleLinkSpecFluentImpl.ApplicationMenuNested<N>> implements ConsoleLinkSpecFluentImpl.ApplicationMenuNested<N>,Nested<N>{
    ApplicationMenuNestedImpl(ApplicationMenuSpec item) {
      this.builder = new ApplicationMenuSpecBuilder(this, item);
    }
    ApplicationMenuNestedImpl() {
      this.builder = new ApplicationMenuSpecBuilder(this);
    }
    ApplicationMenuSpecBuilder builder;
    public N and() {
      return (N) ConsoleLinkSpecFluentImpl.this.withApplicationMenu(builder.build());
    }
    public N endApplicationMenu() {
      return and();
    }
    
  }
  class NamespaceDashboardNestedImpl<N> extends NamespaceDashboardSpecFluentImpl<ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<N>> implements ConsoleLinkSpecFluentImpl.NamespaceDashboardNested<N>,Nested<N>{
    NamespaceDashboardNestedImpl(NamespaceDashboardSpec item) {
      this.builder = new NamespaceDashboardSpecBuilder(this, item);
    }
    NamespaceDashboardNestedImpl() {
      this.builder = new NamespaceDashboardSpecBuilder(this);
    }
    NamespaceDashboardSpecBuilder builder;
    public N and() {
      return (N) ConsoleLinkSpecFluentImpl.this.withNamespaceDashboard(builder.build());
    }
    public N endNamespaceDashboard() {
      return and();
    }
    
  }
  
}
